#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-test
version:              1.7.0.1
visibility:           public
id:                   yesod-test-1.7.0.1-FVEv0wzS8Y81LC9IMQkAQM
key:                  yesod-test-1.7.0.1-FVEv0wzS8Y81LC9IMQkAQM
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  1ff7b586cb11dc47418bc71b833740c6
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.Internal.SIO Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-test-1.7.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-test-1.7.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-test-1.7.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-test
hs-libraries:         HSyesod-test-1.7.0.1-FVEv0wzS8Y81LC9IMQkAQM
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN
    attoparsec-0.14.4-DVQW3zaPrEjFLUvmkAZYCq base-4.18.2.1
    blaze-builder-0.4.4.1-9Evz8oerfDZ9EQvA8PZ07a
    blaze-html-0.9.2.0-IQpYWAMPsDd8u1EAzkbal7
    blaze-markup-0.8.3.0-8LKEXVAssOfaSB46gmUNg bytestring-0.11.5.3
    case-insensitive-1.2.1.0-CbvbZydH4uCGBf3Bqda73d
    conduit-1.3.6.1-BJxsltXT31mLaWStW2N7GT containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    hspec-core-2.11.7-2RMDdDQOJIS9Jlv3hUAFzy
    html-conduit-1.3.2.2-5nQhAacdCMn1Qg5b2lHqXx
    http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-3.1.4.0-946StwFfSrELqUahTPYWqr
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR process-1.6.19.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 wai-3.2.4-HOJRNxSLXyTJ5Lq7jmcw5j
    wai-extra-3.1.18-B7EWthatwHjJCstJt9IxKf
    xml-conduit-1.9.1.4-G1f8ph4UiTy8fbgaTyNDq
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    yesod-core-1.6.28.0-HAu9hokLrLYLH7PVaU1Ycy

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

